import { useTheme } from '@mui/material';
import { ColorUtils } from '@nuskin/foundation-theme';
import { useMemo } from 'react';

const { getGenomeColor } = ColorUtils;
/**
 * Used to fetch the appropriate theme color for primary and contrast.
 * Usually black or similar, and white for contrast.
 * @param toggleValue the CS toggle value between black and white font color.
 * @returns hex value of the color.
 */
const useToggleFontColor = (toggleValue: boolean = false): string => {
    const theme = useTheme();

    return useMemo(
        () => getGenomeColor(theme, 'N10', toggleValue ? 'light' : 'dark'),
        [toggleValue, theme]
    );
};

export default useToggleFontColor;
