import { PropsWithChildren, useMemo } from 'react';
import { useRouter } from 'next/router';

import { BlackWrapper, BlocksContainer } from './Blocks.styled';
import { BodyBlockMap, BodyBlockMapType } from './BlocksMap';
import { getColorName } from '../utils';
import { PageBlocksProps } from '../types';

export type BodyParserProps = {
    body: PageBlocksProps[];
    additionalBlocks?: BodyBlockMapType;
};

const getBlockContentType = (block: PageBlocksProps) => {
    return block?.type;
};

const getBlockData = (block: PageBlocksProps) => {
    return block;
};

const PageBodyParser = (props: PropsWithChildren<BodyParserProps>) => {
    const pageBlocks = props?.body;
    const UIElements: JSX.Element[] = [];
    const { query } = useRouter();
    const regionData = useMemo(() => {
        if (query.language || query.region) {
            return {
                language: query.language,
                region: query.region
            };
        }
        return {};
    }, [query]);
    pageBlocks?.map((block, index) => {
        const contentType = getBlockContentType(block);
        const show = typeof block?.show === 'boolean' ? block.show : true;
        const backgroundImage = block?.background_image?.[0]?.derivatives?.webImage;
        const backgroundColor = !backgroundImage ? getColorName(block?.container_background_color) : 'transparent';
        const includeGap = block.include_gap;
        const containerClass = block?.full_width ? 'container-fluid' : 'container';
        const gapClass = includeGap ? ' !p-0 !pb-4' : ' !p-0';
        if (show || contentType === 'additional_component') {
            const BlocksMap = { ...BodyBlockMap, ...props?.additionalBlocks };
            const BlockComponent = BlocksMap[contentType]?.component;

            if (BlockComponent) {
                const blockData = getBlockData(block);
                UIElements.push(
                    <BlackWrapper
                        bgImage={backgroundImage}
                        className={`${containerClass} ${gapClass} page-body-parser`}
                        key={contentType + index}
                    >
                        <BlocksContainer backgroundColor={backgroundColor} className="blocks-container">
                            <div className="container">
                                <BlockComponent {...blockData} {...regionData} />
                            </div>
                        </BlocksContainer>
                    </BlackWrapper>
                );
            }
        }
    });
    return <>{UIElements}</>;
};

export default PageBodyParser;
