import React, { PropsWithChildren } from 'react';

import { BodyBlockMap } from '../../BlocksMap';
import { PageBlocksProps } from '../../../types';

export type AdditionalComponentProps = {
    components: { [key: string]: PageBlocksProps }[];
};

const getBlockContentType = (block: { [key: string]: PageBlocksProps }) => {
    return Object?.keys(block)?.[0];
};

const AdditionalComponent = (props: PropsWithChildren<AdditionalComponentProps>) => {
    const pageBlocks = props?.components?.find((component) => Object.values(component)?.[0]?.show);
    if (!pageBlocks) return <></>;
    const blocktype = getBlockContentType(pageBlocks);
    const BlockComponent = BodyBlockMap[blocktype]?.component;
    if (!BlockComponent) return <></>;
    return <BlockComponent id={blocktype} {...pageBlocks?.[blocktype]} />;
};

export default AdditionalComponent;
