import { render } from '@testing-library/react';
import React from 'react';

import PageBodyParser from '../BlocksParser';
import { pageBodyColumns } from './fixtures/page-body-contents';
import { pageBodyEmptyHero } from './fixtures/page-body-empty-hero';
import { pageBodyHero } from './fixtures/page-body-hero';

const aboutUsText =
    'Every child deserves a chance to shine. Through our Nu Skin Force for Good Foundation, we’re empowering children around the world with hope for a brighter future.';
describe('Block Parser', () => {
    it('1. should render the page card component for column control with grid', () => {
        const { getByText } = render(<PageBodyParser body={pageBodyColumns.body} />);
        const aboutUsSection = getByText(aboutUsText);
        expect(aboutUsSection).toBeInTheDocument();
    });
    it('2. should render the page card component for column control with flex', () => {
        const item = [
            {
                ...pageBodyColumns.body[0],
                component_reference: [
                    {
                        ...pageBodyColumns.body,
                        use_flex: true
                    }
                ]
            }
        ];
        const { getByText } = render(<PageBodyParser body={item} />);
        const aboutUsSection = getByText(aboutUsText);
        expect(aboutUsSection).toBeInTheDocument();
    });
    it('3. should render the page hero component', () => {
        const { getByText } = render(<PageBodyParser body={pageBodyHero.body} />);
        const hero = getByText('Beauty focus™');
        expect(hero).toBeInTheDocument();
    });
    it('4. should handle if any hero component is empty', () => {
        const { getByText } = render(<PageBodyParser body={pageBodyEmptyHero.body} />);

        const hero = getByText('Beauty focus™');
        expect(hero).toBeInTheDocument();
    });
    it('5. should render null when show is false', () => {
        const item = [{ ...pageBodyHero.body[0], show: false }];
        const { container } = render(<PageBodyParser body={item} />);
        expect(container.querySelector('div div')?.innerHTML).toBe('');
    });
    it('6. should render null when block component is not defined', () => {
        const item = [
            {
                ...pageBodyHero.body[0],
                component_reference: [
                    {
                        ...pageBodyHero.body[0],
                        _content_type_uid: 'test'
                    }
                ]
            }
        ];
        const { container } = render(<PageBodyParser body={item} />);
        expect(container.querySelector('div div')?.innerHTML).toBe('');
    });
});
