import { AllColorKeyType } from '@nuskin/foundation-theme';

export const invert = (flag: boolean) => !flag;
export const emptyFunction = () => null;
export const parseJsonString = (dataString: string) => {
    try {
        return JSON.parse(dataString);
    } catch (error) {
        console.error('error parsing data ', error);
        return {};
    }
};
export const noop = () => { };

export const isBrowser = () => {
    return typeof window !== 'undefined';
};
/**
 * input colorExtensionString
 * '{ "brandColor": { "colorName": "A10", "colorObj": { "light": "#E5EDF6", "dark": "#14324F" } } }'
 * output colorName 'A10'
 */
export const getColorName = (
    colorExtensionString: string = '',
    defaultColorName = 'transparent'
): AllColorKeyType => {
    return parseJsonString(colorExtensionString)?.brandColor?.colorName ?? defaultColorName;
};

export const getRandomUid = () => (Math.random() * 100).toFixed(0) + '';

export const formatCurrency = (amount: number = 0, currencyCode: string = 'USD', locale: string) => {
    const currencyFormatter = new Intl.NumberFormat(locale = 'en-US', {
        style: 'currency',
        currency: currencyCode,
        minimumFractionDigits: 2
    });

    return currencyFormatter.format(amount);
};