import { fetchApi } from '../fetch-utils';


describe('Fetch Utils', () => {
    let fakeFetch: jest.Mock<Promise<Response>>;
    beforeEach(() => {
        fakeFetch = jest.fn(() => {
            return Promise.resolve({
                json: []
            }) as Promise<any>;
        });
        window.fetch = fakeFetch;
    });
    it('1. fetchApi should return promise reject when endpoint not passed ', async () => {
        const response = fetchApi({
            method: 'GET'
        });
        await expect(response).rejects.toEqual('endpoint url not defined');
    });
    it('2. fetchApi to call with default headers', async () => {
        try {
            await fetchApi({
                endpoint: 'test',
                method: 'GET'
            });
            const fakeFetchCall = fakeFetch.mock.calls[0][1];
            expect(fakeFetchCall.headers).toHaveProperty('Accept');
            expect(fakeFetchCall.headers).toHaveProperty('Content-Type');
        } catch (err) { /* empty */ } 
    });
    it('3. fetchApi to call with correct param', async () => {
        try {
            await fetchApi({
                endpoint: 'test',
                method: 'GET',
                options: {
                    headers: {
                        'x-sk-session-id': 1234
                    }
                }
            });
            const fakeFetchCall = fakeFetch.mock.calls[0][1];
            expect(fakeFetchCall.headers).toHaveProperty('x-sk-session-id');
        } catch (err) { /* empty */ }
    });
    it('3. fetchApi to call with correct method and mode', async () => {
        try {
            await fetchApi({
                endpoint: 'test',
                method: 'POST'
            });
            const fakeFetchCall = fakeFetch.mock.calls[0][1];
            expect(fakeFetchCall.method).toEqual('POST');
            expect(fakeFetchCall.mode).toEqual('cors');
        } catch (err) { /* empty */ }
    });
    it('4. fetchApi to call with correct payload', async () => {
        try {
            await fetchApi({
                endpoint: 'test',
                method: 'POST',
                payload: {
                    param: '1'
                }
            });
            const fakeFetchCall = fakeFetch.mock.calls[0][1];
            expect(fakeFetchCall.body).toEqual(JSON.stringify({ param: '1' }));
        } catch (err) { /* empty */ }
    });

});

